;;; ucs-util.el --- Character Database utility

;; Copyright (C) 1998 MORIOKA Tomohiko.

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Keywords: ISO/IEC 10646, Unicode, UCS-4, UTF-8, MULE.

;; This file is part of XEmacs-UCS.

;; XEmacs-UCS is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published
;; by the Free Software Foundation; either version 2, or (at your
;; option) any later version.

;; XEmacs-UCS is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with XEmacs; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
;; 02111-1307, USA.

;;; Code:

(defun ucs-set-char (code char)
  (set-char-ucs char code)
  (set-ucs-char code char)
  )

(defun ucs-define-ideograph (code radical stroke &rest chars)
  (set-ucs-char code (car chars))
  (while chars
    (set-char-ucs (car chars) code)
    (setq chars (cdr chars))
    ))

(provide 'ucs-util)

;;; ucs-util.el ends here
