;;; uni-cjk-c-ideo.el --- UCS table of CJK Compatibility Ideographs

;; Copyright (C) 1998 MORIOKA Tomohiko.

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Keywords: ISO/IEC 10646, Unicode, charset, MULE,
;;           CJK Compatibility Ideographs

;; This file is part of XEmacs-UCS.

;; XEmacs-UCS is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published
;; by the Free Software Foundation; either version 2, or (at your
;; option) any later version.

;; XEmacs-UCS is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with XEmacs; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
;; 02111-1307, USA.

;;; Code:

(require 'ucs-util)

(ucs-set-char #xF900 ?豈) ; KS0-C-4B50
(ucs-set-char #xF901 ?更) ; KS0-C-4B56
(ucs-set-char #xF902 ?車) ; KS0-C-4B67
(ucs-set-char #xF903 ?賈) ; KS0-C-4D4F
(ucs-set-char #xF904 ?滑) ; KS0-C-4D68
(ucs-set-char #xF905 ?串) ; KS0-C-4E2D
(ucs-set-char #xF906 ?句) ; KS0-C-4F7B
(ucs-set-char #xF907 ?龜) ; KS0-C-5022
(ucs-set-char #xF908 ?龜) ; KS0-C-5038
(ucs-set-char #xF909 ?契) ; KS0-C-5050
(ucs-set-char #xF90A ?金) ; KS0-C-505D
(ucs-set-char #xF90B ?喇) ; KS0-C-5154
(ucs-set-char #xF90C ?奈) ; KS0-C-5155
(ucs-set-char #xF90D ?懶) ; KS0-C-5158
(ucs-set-char #xF90E ?癩) ; KS0-C-515B
(ucs-set-char #xF90F ?羅) ; KS0-C-515C
(ucs-set-char #xF910 ?蘿) ; KS0-C-515D
(ucs-set-char #xF911 ?螺) ; KS0-C-515E
(ucs-set-char #xF912 ?裸) ; KS0-C-515F
(ucs-set-char #xF913 ?邏) ; KS0-C-5160
(ucs-set-char #xF914 ?樂) ; KS0-C-5162
(ucs-set-char #xF915 ?洛) ; KS0-C-5163
(ucs-set-char #xF916 ?烙) ; KS0-C-5164
(ucs-set-char #xF917 ?珞) ; KS0-C-5165
(ucs-set-char #xF918 ?落) ; KS0-C-5166
(ucs-set-char #xF919 ?酪) ; KS0-C-5168
(ucs-set-char #xF91A ?駱) ; KS0-C-5169
(ucs-set-char #xF91B ?亂) ; KS0-C-516A
(ucs-set-char #xF91C ?卵) ; KS0-C-516B
(ucs-set-char #xF91D ?欄) ; KS0-C-516D
(ucs-set-char #xF91E ?爛) ; KS0-C-516F
(ucs-set-char #xF91F ?蘭) ; KS0-C-5170
(ucs-set-char #xF920 ?鸞) ; KS0-C-5172
(ucs-set-char #xF921 ?嵐) ; KS0-C-5176
(ucs-set-char #xF922 ?濫) ; KS0-C-517A
(ucs-set-char #xF923 ?藍) ; KS0-C-517C
(ucs-set-char #xF924 ?襤) ; KS0-C-517D
(ucs-set-char #xF925 ?拉) ; KS0-C-517E
(ucs-set-char #xF926 ?臘) ; KS0-C-5222
(ucs-set-char #xF927 ?蠟) ; KS0-C-5223
(ucs-set-char #xF928 ?廊) ; KS0-C-5227
(ucs-set-char #xF929 ?朗) ; KS0-C-5228
(ucs-set-char #xF92A ?浪) ; KS0-C-5229
(ucs-set-char #xF92B ?狼) ; KS0-C-522A
(ucs-set-char #xF92C ?郎) ; KS0-C-522B
(ucs-set-char #xF92D ?來) ; KS0-C-522D
(ucs-set-char #xF92E ?冷) ; KS0-C-5232
(ucs-set-char #xF92F ?勞) ; KS0-C-523E
(ucs-set-char #xF930 ?擄) ; KS0-C-5242
(ucs-set-char #xF931 ?櫓) ; KS0-C-5243
(ucs-set-char #xF932 ?爐) ; KS0-C-5244
(ucs-set-char #xF933 ?盧) ; KS0-C-5246
(ucs-set-char #xF934 ?老) ; KS0-C-5247
(ucs-set-char #xF935 ?蘆) ; KS0-C-5248
(ucs-set-char #xF936 ?虜) ; KS0-C-5249
(ucs-set-char #xF937 ?路) ; KS0-C-524A
(ucs-set-char #xF938 ?露) ; KS0-C-524B
(ucs-set-char #xF939 ?魯) ; KS0-C-524D
(ucs-set-char #xF93A ?鷺) ; KS0-C-524E
(ucs-set-char #xF93B ?碌) ; KS0-C-524F
(ucs-set-char #xF93C ?祿) ; KS0-C-5250
(ucs-set-char #xF93D ?綠) ; KS0-C-5251
(ucs-set-char #xF93E ?菉) ; KS0-C-5252
(ucs-set-char #xF93F ?錄) ; KS0-C-5253
(ucs-set-char #xF940 ?鹿) ; KS0-C-5254
(ucs-set-char #xF941 ?論) ; KS0-C-5255
(ucs-set-char #xF942 ?壟) ; KS0-C-5256
(ucs-set-char #xF943 ?弄) ; KS0-C-5257
(ucs-set-char #xF944 ?籠) ; KS0-C-5259
(ucs-set-char #xF945 ?聾) ; KS0-C-525A
(ucs-set-char #xF946 ?牢) ; KS0-C-525E
(ucs-set-char #xF947 ?磊) ; KS0-C-525F
(ucs-set-char #xF948 ?賂) ; KS0-C-5261
(ucs-set-char #xF949 ?雷) ; KS0-C-5262
(ucs-set-char #xF94A ?壘) ; KS0-C-5264
(ucs-set-char #xF94B ?屢) ; KS0-C-5265
(ucs-set-char #xF94C ?樓) ; KS0-C-5266
(ucs-set-char #xF94D ?淚) ; KS0-C-5267
(ucs-set-char #xF94E ?漏) ; KS0-C-5268
(ucs-set-char #xF94F ?累) ; KS0-C-5269
(ucs-set-char #xF950 ?縷) ; KS0-C-526A
(ucs-set-char #xF951 ?陋) ; KS0-C-526B
(ucs-set-char #xF952 ?勒) ; KS0-C-5270
(ucs-set-char #xF953 ?肋) ; KS0-C-5271
(ucs-set-char #xF954 ?凜) ; KS0-C-5272
(ucs-set-char #xF955 ?凌) ; KS0-C-5273
(ucs-set-char #xF956 ?稜) ; KS0-C-5274
(ucs-set-char #xF957 ?綾) ; KS0-C-5275
(ucs-set-char #xF958 ?菱) ; KS0-C-5277
(ucs-set-char #xF959 ?陵) ; KS0-C-5278
(ucs-set-char #xF95A ?讀) ; KS0-C-5466
(ucs-set-char #xF95B ?拏) ; KS0-C-547C
(ucs-set-char #xF95C ?樂) ; KS0-C-5525
(ucs-set-char #xF95D ?諾) ; KS0-C-552B
(ucs-set-char #xF95E ?丹) ; KS0-C-552E
(ucs-set-char #xF95F ?寧) ; KS0-C-5638
(ucs-set-char #xF960 ?怒) ; KS0-C-564D
(ucs-set-char #xF961 ?率) ; KS0-C-574B
(ucs-set-char #xF962 ?異) ; KS0-C-5764
(ucs-set-char #xF963 ?北) ; KS0-C-5B45
(ucs-set-char #xF964 ?磻) ; KS0-C-5B64
(ucs-set-char #xF965 ?便) ; KS0-C-5C25
(ucs-set-char #xF966 ?復) ; KS0-C-5D25
(ucs-set-char #xF967 ?不) ; KS0-C-5D55
(ucs-set-char #xF968 ?泌) ; KS0-C-5D74
(ucs-set-char #xF969 ?數) ; KS0-C-5E7C
(ucs-set-char #xF96A ?索) ; KS0-C-5E7E
(ucs-set-char #xF96B ?參) ; KS0-C-5F33
(ucs-set-char #xF96C ?塞) ; KS0-C-5F61
(ucs-set-char #xF96D ?省) ; KS0-C-5F68
(ucs-set-char #xF96E ?葉) ; KS0-C-6071
(ucs-set-char #xF96F ?說) ; KS0-C-612D
(ucs-set-char #xF970 ?殺) ; KS0-C-616D
(ucs-set-char #xF971 ?辰) ; KS0-C-6375
(ucs-set-char #xF972 ?沈) ; KS0-C-6421
(ucs-set-char #xF973 ?拾) ; KS0-C-6429
(ucs-set-char #xF974 ?若) ; KS0-C-652E
(ucs-set-char #xF975 ?掠) ; KS0-C-6531
(ucs-set-char #xF976 ?略) ; KS0-C-6532
(ucs-set-char #xF977 ?亮) ; KS0-C-6539
(ucs-set-char #xF978 ?兩) ; KS0-C-653B
(ucs-set-char #xF979 ?凉) ; KS0-C-653C
(ucs-set-char #xF97A ?梁) ; KS0-C-6544
(ucs-set-char #xF97B ?糧) ; KS0-C-654E
(ucs-set-char #xF97C ?良) ; KS0-C-6550
(ucs-set-char #xF97D ?諒) ; KS0-C-6552
(ucs-set-char #xF97E ?量) ; KS0-C-6556
(ucs-set-char #xF97F ?勵) ; KS0-C-657A
(ucs-set-char #xF980 ?呂) ; KS0-C-657B
(ucs-set-char #xF981 ?女) ; KS0-C-657C
(ucs-set-char #xF982 ?廬) ; KS0-C-657E
(ucs-set-char #xF983 ?旅) ; KS0-C-6621
(ucs-set-char #xF984 ?濾) ; KS0-C-6624
(ucs-set-char #xF985 ?礪) ; KS0-C-6627
(ucs-set-char #xF986 ?閭) ; KS0-C-662D
(ucs-set-char #xF987 ?驪) ; KS0-C-662F
(ucs-set-char #xF988 ?麗) ; KS0-C-6630
(ucs-set-char #xF989 ?黎) ; KS0-C-6631
(ucs-set-char #xF98A ?力) ; KS0-C-6633
(ucs-set-char #xF98B ?曆) ; KS0-C-6637
(ucs-set-char #xF98C ?歷) ; KS0-C-6638
(ucs-set-char #xF98D ?轢) ; KS0-C-663C
(ucs-set-char #xF98E ?年) ; KS0-C-6644
(ucs-set-char #xF98F ?憐) ; KS0-C-6646
(ucs-set-char #xF990 ?戀) ; KS0-C-6647
(ucs-set-char #xF991 ?撚) ; KS0-C-664A
(ucs-set-char #xF992 ?漣) ; KS0-C-6652
(ucs-set-char #xF993 ?煉) ; KS0-C-6656
(ucs-set-char #xF994 ?璉) ; KS0-C-6659
(ucs-set-char #xF995 ?秊) ; KS0-C-665C
(ucs-set-char #xF996 ?練) ; KS0-C-665F
(ucs-set-char #xF997 ?聯) ; KS0-C-6661
(ucs-set-char #xF998 ?輦) ; KS0-C-6664
(ucs-set-char #xF999 ?蓮) ; KS0-C-6665
(ucs-set-char #xF99A ?連) ; KS0-C-6666
(ucs-set-char #xF99B ?鍊) ; KS0-C-6668
(ucs-set-char #xF99C ?列) ; KS0-C-666A
(ucs-set-char #xF99D ?劣) ; KS0-C-666B
(ucs-set-char #xF99E ?咽) ; KS0-C-666C
(ucs-set-char #xF99F ?烈) ; KS0-C-666F
(ucs-set-char #xF9A0 ?裂) ; KS0-C-6671
(ucs-set-char #xF9A1 ?說) ; KS0-C-6672
(ucs-set-char #xF9A2 ?廉) ; KS0-C-6675
(ucs-set-char #xF9A3 ?念) ; KS0-C-6676
(ucs-set-char #xF9A4 ?捻) ; KS0-C-6677
(ucs-set-char #xF9A5 ?殮) ; KS0-C-6679
(ucs-set-char #xF9A6 ?簾) ; KS0-C-6721
(ucs-set-char #xF9A7 ?獵) ; KS0-C-6726
(ucs-set-char #xF9A8 ?令) ; KS0-C-6729
(ucs-set-char #xF9A9 ?囹) ; KS0-C-672A
(ucs-set-char #xF9AA ?寧) ; KS0-C-672C
(ucs-set-char #xF9AB ?嶺) ; KS0-C-672D
(ucs-set-char #xF9AC ?怜) ; KS0-C-6730
(ucs-set-char #xF9AD ?玲) ; KS0-C-673F
(ucs-set-char #xF9AE ?瑩) ; KS0-C-6741
(ucs-set-char #xF9AF ?羚) ; KS0-C-6746
(ucs-set-char #xF9B0 ?聆) ; KS0-C-6747
(ucs-set-char #xF9B1 ?鈴) ; KS0-C-674B
(ucs-set-char #xF9B2 ?零) ; KS0-C-674D
(ucs-set-char #xF9B3 ?靈) ; KS0-C-674F
(ucs-set-char #xF9B4 ?領) ; KS0-C-6750
(ucs-set-char #xF9B5 ?例) ; KS0-C-6753
(ucs-set-char #xF9B6 ?禮) ; KS0-C-675F
(ucs-set-char #xF9B7 ?醴) ; KS0-C-6764
(ucs-set-char #xF9B8 ?隸) ; KS0-C-6766
(ucs-set-char #xF9B9 ?惡) ; KS0-C-6777
(ucs-set-char #xF9BA ?了) ; KS0-C-6867
(ucs-set-char #xF9BB ?僚) ; KS0-C-6868
(ucs-set-char #xF9BC ?寮) ; KS0-C-6870
(ucs-set-char #xF9BD ?尿) ; KS0-C-6871
(ucs-set-char #xF9BE ?料) ; KS0-C-6877
(ucs-set-char #xF9BF ?樂) ; KS0-C-6879
(ucs-set-char #xF9C0 ?燎) ; KS0-C-687B
(ucs-set-char #xF9C1 ?療) ; KS0-C-687E
(ucs-set-char #xF9C2 ?蓼) ; KS0-C-6927
(ucs-set-char #xF9C3 ?遼) ; KS0-C-692C
(ucs-set-char #xF9C4 ?龍) ; KS0-C-694C
(ucs-set-char #xF9C5 ?暈) ; KS0-C-6977
(ucs-set-char #xF9C6 ?阮) ; KS0-C-6A41
(ucs-set-char #xF9C7 ?劉) ; KS0-C-6A65
(ucs-set-char #xF9C8 ?杻) ; KS0-C-6A74
(ucs-set-char #xF9C9 ?柳) ; KS0-C-6A77
(ucs-set-char #xF9CA ?流) ; KS0-C-6A7C
(ucs-set-char #xF9CB ?溜) ; KS0-C-6A7E
(ucs-set-char #xF9CC ?琉) ; KS0-C-6B24
(ucs-set-char #xF9CD ?留) ; KS0-C-6B27
(ucs-set-char #xF9CE ?硫) ; KS0-C-6B29
(ucs-set-char #xF9CF ?紐) ; KS0-C-6B2A
(ucs-set-char #xF9D0 ?類) ; KS0-C-6B3A
(ucs-set-char #xF9D1 ?六) ; KS0-C-6B3B
(ucs-set-char #xF9D2 ?戮) ; KS0-C-6B3D
(ucs-set-char #xF9D3 ?陸) ; KS0-C-6B41
(ucs-set-char #xF9D4 ?倫) ; KS0-C-6B42
(ucs-set-char #xF9D5 ?崙) ; KS0-C-6B46
(ucs-set-char #xF9D6 ?淪) ; KS0-C-6B47
(ucs-set-char #xF9D7 ?輪) ; KS0-C-6B4C
(ucs-set-char #xF9D8 ?律) ; KS0-C-6B4F
(ucs-set-char #xF9D9 ?慄) ; KS0-C-6B50
(ucs-set-char #xF9DA ?栗) ; KS0-C-6B51
(ucs-set-char #xF9DB ?率) ; KS0-C-6B52
(ucs-set-char #xF9DC ?隆) ; KS0-C-6B58
(ucs-set-char #xF9DD ?利) ; KS0-C-6C26
(ucs-set-char #xF9DE ?吏) ; KS0-C-6C27
(ucs-set-char #xF9DF ?履) ; KS0-C-6C2A
(ucs-set-char #xF9E0 ?易) ; KS0-C-6C2F
(ucs-set-char #xF9E1 ?李) ; KS0-C-6C30
(ucs-set-char #xF9E2 ?梨) ; KS0-C-6C31
(ucs-set-char #xF9E3 ?泥) ; KS0-C-6C32
(ucs-set-char #xF9E4 ?理) ; KS0-C-6C35
(ucs-set-char #xF9E5 ?痢) ; KS0-C-6C38
(ucs-set-char #xF9E6 ?罹) ; KS0-C-6C3A
(ucs-set-char #xF9E7 ?裏) ; KS0-C-6C40
(ucs-set-char #xF9E8 ?裡) ; KS0-C-6C41
(ucs-set-char #xF9E9 ?里) ; KS0-C-6C45
(ucs-set-char #xF9EA ?離) ; KS0-C-6C46
(ucs-set-char #xF9EB ?匿) ; KS0-C-6C49
(ucs-set-char #xF9EC ?溺) ; KS0-C-6C4A
(ucs-set-char #xF9ED ?吝) ; KS0-C-6C55
(ucs-set-char #xF9EE ?燐) ; KS0-C-6C5D
(ucs-set-char #xF9EF ?璘) ; KS0-C-6C5E
(ucs-set-char #xF9F0 ?藺) ; KS0-C-6C61
(ucs-set-char #xF9F1 ?隣) ; KS0-C-6C64
(ucs-set-char #xF9F2 ?鱗) ; KS0-C-6C67
(ucs-set-char #xF9F3 ?麟) ; KS0-C-6C68
(ucs-set-char #xF9F4 ?林) ; KS0-C-6C77
(ucs-set-char #xF9F5 ?淋) ; KS0-C-6C78
(ucs-set-char #xF9F6 ?臨) ; KS0-C-6C7A
(ucs-set-char #xF9F7 ?立) ; KS0-C-6D21
(ucs-set-char #xF9F8 ?笠) ; KS0-C-6D22
(ucs-set-char #xF9F9 ?粒) ; KS0-C-6D23
(ucs-set-char #xF9FA ?狀) ; KS0-C-6D6E
(ucs-set-char #xF9FB ?炙) ; KS0-C-6E5B
(ucs-set-char #xF9FC ?識) ; KS0-C-723D
(ucs-set-char #xF9FD ?什) ; KS0-C-727A
(ucs-set-char #xF9FE ?茶) ; KS0-C-7331
(ucs-set-char #xF9FF ?刺) ; KS0-C-7427
(ucs-set-char #xFA00 ?切) ; KS0-C-746E
(ucs-set-char #xFA01 ?度) ; KS0-C-7674
(ucs-set-char #xFA02 ?拓) ; KS0-C-7676
(ucs-set-char #xFA03 ?糖) ; KS0-C-7738
(ucs-set-char #xFA04 ?宅) ; KS0-C-7748
(ucs-set-char #xFA05 ?洞) ; KS0-C-7753
(ucs-set-char #xFA06 ?暴) ; KS0-C-785B
(ucs-set-char #xFA07 ?輻) ; KS0-C-7870
(ucs-set-char #xFA08 ?行) ; KS0-C-7A21
(ucs-set-char #xFA09 ?降) ; KS0-C-7A22
(ucs-set-char #xFA0A ?見) ; KS0-C-7A66
(ucs-set-char #xFA0B ?廓) ; KS0-C-7C29

;;; uni-cjk-c-ideo.el ends here
