;;; ucs-katakana.el --- UCS table of Katakana

;; Copyright (C) 1998 MORIOKA Tomohiko.

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Keywords: ISO/IEC 10646, Unicode, charset, MULE, Katakana

;; This file is part of XEmacs-UCS.

;; XEmacs-UCS is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published
;; by the Free Software Foundation; either version 2, or (at your
;; option) any later version.

;; XEmacs-UCS is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with XEmacs; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
;; 02111-1307, USA.

;;; Code:

(require 'ucs-util)

(ucs-set-char #x30A1 ?ァ) ; KS0-C-2B21
(ucs-set-char #x30A1 ?ァ) ; J78-@-2521
(ucs-set-char #x30A1 ?ァ) ; GB0-A-2521
(ucs-set-char #x30A1 ?ァ) ; J83-B-2521

(ucs-set-char #x30A2 ?ア) ; KS0-C-2B22
(ucs-set-char #x30A2 ?ア) ; J78-@-2522
(ucs-set-char #x30A2 ?ア) ; GB0-A-2522
(ucs-set-char #x30A2 ?ア) ; J83-B-2522

(ucs-set-char #x30A3 ?ィ) ; KS0-C-2B23
(ucs-set-char #x30A3 ?ィ) ; J78-@-2523
(ucs-set-char #x30A3 ?ィ) ; GB0-A-2523
(ucs-set-char #x30A3 ?ィ) ; J83-B-2523

(ucs-set-char #x30A4 ?イ) ; KS0-C-2B24
(ucs-set-char #x30A4 ?イ) ; J78-@-2524
(ucs-set-char #x30A4 ?イ) ; GB0-A-2524
(ucs-set-char #x30A4 ?イ) ; J83-B-2524

(ucs-set-char #x30A5 ?ゥ) ; KS0-C-2B25
(ucs-set-char #x30A5 ?ゥ) ; J78-@-2525
(ucs-set-char #x30A5 ?ゥ) ; GB0-A-2525
(ucs-set-char #x30A5 ?ゥ) ; J83-B-2525

(ucs-set-char #x30A6 ?ウ) ; KS0-C-2B26
(ucs-set-char #x30A6 ?ウ) ; J78-@-2526
(ucs-set-char #x30A6 ?ウ) ; GB0-A-2526
(ucs-set-char #x30A6 ?ウ) ; J83-B-2526

(ucs-set-char #x30A7 ?ェ) ; KS0-C-2B27
(ucs-set-char #x30A7 ?ェ) ; J78-@-2527
(ucs-set-char #x30A7 ?ェ) ; GB0-A-2527
(ucs-set-char #x30A7 ?ェ) ; J83-B-2527

(ucs-set-char #x30A8 ?エ) ; KS0-C-2B28
(ucs-set-char #x30A8 ?エ) ; J78-@-2528
(ucs-set-char #x30A8 ?エ) ; GB0-A-2528
(ucs-set-char #x30A8 ?エ) ; J83-B-2528

(ucs-set-char #x30A9 ?ォ) ; KS0-C-2B29
(ucs-set-char #x30A9 ?ォ) ; J78-@-2529
(ucs-set-char #x30A9 ?ォ) ; GB0-A-2529
(ucs-set-char #x30A9 ?ォ) ; J83-B-2529

(ucs-set-char #x30AA ?オ) ; KS0-C-2B2A
(ucs-set-char #x30AA ?オ) ; J78-@-252A
(ucs-set-char #x30AA ?オ) ; GB0-A-252A
(ucs-set-char #x30AA ?オ) ; J83-B-252A

(ucs-set-char #x30AB ?カ) ; KS0-C-2B2B
(ucs-set-char #x30AB ?カ) ; J78-@-252B
(ucs-set-char #x30AB ?カ) ; GB0-A-252B
(ucs-set-char #x30AB ?カ) ; J83-B-252B

(ucs-set-char #x30AC ?ガ) ; KS0-C-2B2C
(ucs-set-char #x30AC ?ガ) ; J78-@-252C
(ucs-set-char #x30AC ?ガ) ; GB0-A-252C
(ucs-set-char #x30AC ?ガ) ; J83-B-252C

(ucs-set-char #x30AD ?キ) ; KS0-C-2B2D
(ucs-set-char #x30AD ?キ) ; J78-@-252D
(ucs-set-char #x30AD ?キ) ; GB0-A-252D
(ucs-set-char #x30AD ?キ) ; J83-B-252D

(ucs-set-char #x30AE ?ギ) ; KS0-C-2B2E
(ucs-set-char #x30AE ?ギ) ; J78-@-252E
(ucs-set-char #x30AE ?ギ) ; GB0-A-252E
(ucs-set-char #x30AE ?ギ) ; J83-B-252E

(ucs-set-char #x30AF ?ク) ; KS0-C-2B2F
(ucs-set-char #x30AF ?ク) ; J78-@-252F
(ucs-set-char #x30AF ?ク) ; GB0-A-252F
(ucs-set-char #x30AF ?ク) ; J83-B-252F

(ucs-set-char #x30B0 ?グ) ; KS0-C-2B30
(ucs-set-char #x30B0 ?グ) ; J78-@-2530
(ucs-set-char #x30B0 ?グ) ; GB0-A-2530
(ucs-set-char #x30B0 ?グ) ; J83-B-2530

(ucs-set-char #x30B1 ?ケ) ; KS0-C-2B31
(ucs-set-char #x30B1 ?ケ) ; J78-@-2531
(ucs-set-char #x30B1 ?ケ) ; GB0-A-2531
(ucs-set-char #x30B1 ?ケ) ; J83-B-2531

(ucs-set-char #x30B2 ?ゲ) ; KS0-C-2B32
(ucs-set-char #x30B2 ?ゲ) ; J78-@-2532
(ucs-set-char #x30B2 ?ゲ) ; GB0-A-2532
(ucs-set-char #x30B2 ?ゲ) ; J83-B-2532

(ucs-set-char #x30B3 ?コ) ; KS0-C-2B33
(ucs-set-char #x30B3 ?コ) ; J78-@-2533
(ucs-set-char #x30B3 ?コ) ; GB0-A-2533
(ucs-set-char #x30B3 ?コ) ; J83-B-2533

(ucs-set-char #x30B4 ?ゴ) ; KS0-C-2B34
(ucs-set-char #x30B4 ?ゴ) ; J78-@-2534
(ucs-set-char #x30B4 ?ゴ) ; GB0-A-2534
(ucs-set-char #x30B4 ?ゴ) ; J83-B-2534

(ucs-set-char #x30B5 ?サ) ; KS0-C-2B35
(ucs-set-char #x30B5 ?サ) ; J78-@-2535
(ucs-set-char #x30B5 ?サ) ; GB0-A-2535
(ucs-set-char #x30B5 ?サ) ; J83-B-2535

(ucs-set-char #x30B6 ?ザ) ; KS0-C-2B36
(ucs-set-char #x30B6 ?ザ) ; J78-@-2536
(ucs-set-char #x30B6 ?ザ) ; GB0-A-2536
(ucs-set-char #x30B6 ?ザ) ; J83-B-2536

(ucs-set-char #x30B7 ?シ) ; KS0-C-2B37
(ucs-set-char #x30B7 ?シ) ; J78-@-2537
(ucs-set-char #x30B7 ?シ) ; GB0-A-2537
(ucs-set-char #x30B7 ?シ) ; J83-B-2537

(ucs-set-char #x30B8 ?ジ) ; KS0-C-2B38
(ucs-set-char #x30B8 ?ジ) ; J78-@-2538
(ucs-set-char #x30B8 ?ジ) ; GB0-A-2538
(ucs-set-char #x30B8 ?ジ) ; J83-B-2538

(ucs-set-char #x30B9 ?ス) ; KS0-C-2B39
(ucs-set-char #x30B9 ?ス) ; J78-@-2539
(ucs-set-char #x30B9 ?ス) ; GB0-A-2539
(ucs-set-char #x30B9 ?ス) ; J83-B-2539

(ucs-set-char #x30BA ?ズ) ; KS0-C-2B3A
(ucs-set-char #x30BA ?ズ) ; J78-@-253A
(ucs-set-char #x30BA ?ズ) ; GB0-A-253A
(ucs-set-char #x30BA ?ズ) ; J83-B-253A

(ucs-set-char #x30BB ?セ) ; KS0-C-2B3B
(ucs-set-char #x30BB ?セ) ; J78-@-253B
(ucs-set-char #x30BB ?セ) ; GB0-A-253B
(ucs-set-char #x30BB ?セ) ; J83-B-253B

(ucs-set-char #x30BC ?ゼ) ; KS0-C-2B3C
(ucs-set-char #x30BC ?ゼ) ; J78-@-253C
(ucs-set-char #x30BC ?ゼ) ; GB0-A-253C
(ucs-set-char #x30BC ?ゼ) ; J83-B-253C

(ucs-set-char #x30BD ?ソ) ; KS0-C-2B3D
(ucs-set-char #x30BD ?ソ) ; J78-@-253D
(ucs-set-char #x30BD ?ソ) ; GB0-A-253D
(ucs-set-char #x30BD ?ソ) ; J83-B-253D

(ucs-set-char #x30BE ?ゾ) ; KS0-C-2B3E
(ucs-set-char #x30BE ?ゾ) ; J78-@-253E
(ucs-set-char #x30BE ?ゾ) ; GB0-A-253E
(ucs-set-char #x30BE ?ゾ) ; J83-B-253E

(ucs-set-char #x30BF ?タ) ; KS0-C-2B3F
(ucs-set-char #x30BF ?タ) ; J78-@-253F
(ucs-set-char #x30BF ?タ) ; GB0-A-253F
(ucs-set-char #x30BF ?タ) ; J83-B-253F

(ucs-set-char #x30C0 ?ダ) ; KS0-C-2B40
(ucs-set-char #x30C0 ?ダ) ; J78-@-2540
(ucs-set-char #x30C0 ?ダ) ; GB0-A-2540
(ucs-set-char #x30C0 ?ダ) ; J83-B-2540

(ucs-set-char #x30C1 ?チ) ; KS0-C-2B41
(ucs-set-char #x30C1 ?チ) ; J78-@-2541
(ucs-set-char #x30C1 ?チ) ; GB0-A-2541
(ucs-set-char #x30C1 ?チ) ; J83-B-2541

(ucs-set-char #x30C2 ?ヂ) ; KS0-C-2B42
(ucs-set-char #x30C2 ?ヂ) ; J78-@-2542
(ucs-set-char #x30C2 ?ヂ) ; GB0-A-2542
(ucs-set-char #x30C2 ?ヂ) ; J83-B-2542

(ucs-set-char #x30C3 ?ッ) ; KS0-C-2B43
(ucs-set-char #x30C3 ?ッ) ; J78-@-2543
(ucs-set-char #x30C3 ?ッ) ; GB0-A-2543
(ucs-set-char #x30C3 ?ッ) ; J83-B-2543

(ucs-set-char #x30C4 ?ツ) ; KS0-C-2B44
(ucs-set-char #x30C4 ?ツ) ; J78-@-2544
(ucs-set-char #x30C4 ?ツ) ; GB0-A-2544
(ucs-set-char #x30C4 ?ツ) ; J83-B-2544

(ucs-set-char #x30C5 ?ヅ) ; KS0-C-2B45
(ucs-set-char #x30C5 ?ヅ) ; J78-@-2545
(ucs-set-char #x30C5 ?ヅ) ; GB0-A-2545
(ucs-set-char #x30C5 ?ヅ) ; J83-B-2545

(ucs-set-char #x30C6 ?テ) ; KS0-C-2B46
(ucs-set-char #x30C6 ?テ) ; J78-@-2546
(ucs-set-char #x30C6 ?テ) ; GB0-A-2546
(ucs-set-char #x30C6 ?テ) ; J83-B-2546

(ucs-set-char #x30C7 ?デ) ; KS0-C-2B47
(ucs-set-char #x30C7 ?デ) ; J78-@-2547
(ucs-set-char #x30C7 ?デ) ; GB0-A-2547
(ucs-set-char #x30C7 ?デ) ; J83-B-2547

(ucs-set-char #x30C8 ?ト) ; KS0-C-2B48
(ucs-set-char #x30C8 ?ト) ; J78-@-2548
(ucs-set-char #x30C8 ?ト) ; GB0-A-2548
(ucs-set-char #x30C8 ?ト) ; J83-B-2548

(ucs-set-char #x30C9 ?ド) ; KS0-C-2B49
(ucs-set-char #x30C9 ?ド) ; J78-@-2549
(ucs-set-char #x30C9 ?ド) ; GB0-A-2549
(ucs-set-char #x30C9 ?ド) ; J83-B-2549

(ucs-set-char #x30CA ?ナ) ; KS0-C-2B4A
(ucs-set-char #x30CA ?ナ) ; J78-@-254A
(ucs-set-char #x30CA ?ナ) ; GB0-A-254A
(ucs-set-char #x30CA ?ナ) ; J83-B-254A

(ucs-set-char #x30CB ?ニ) ; KS0-C-2B4B
(ucs-set-char #x30CB ?ニ) ; J78-@-254B
(ucs-set-char #x30CB ?ニ) ; GB0-A-254B
(ucs-set-char #x30CB ?ニ) ; J83-B-254B

(ucs-set-char #x30CC ?ヌ) ; KS0-C-2B4C
(ucs-set-char #x30CC ?ヌ) ; J78-@-254C
(ucs-set-char #x30CC ?ヌ) ; GB0-A-254C
(ucs-set-char #x30CC ?ヌ) ; J83-B-254C

(ucs-set-char #x30CD ?ネ) ; KS0-C-2B4D
(ucs-set-char #x30CD ?ネ) ; J78-@-254D
(ucs-set-char #x30CD ?ネ) ; GB0-A-254D
(ucs-set-char #x30CD ?ネ) ; J83-B-254D

(ucs-set-char #x30CE ?ノ) ; KS0-C-2B4E
(ucs-set-char #x30CE ?ノ) ; J78-@-254E
(ucs-set-char #x30CE ?ノ) ; GB0-A-254E
(ucs-set-char #x30CE ?ノ) ; J83-B-254E

(ucs-set-char #x30CF ?ハ) ; KS0-C-2B4F
(ucs-set-char #x30CF ?ハ) ; J78-@-254F
(ucs-set-char #x30CF ?ハ) ; GB0-A-254F
(ucs-set-char #x30CF ?ハ) ; J83-B-254F

(ucs-set-char #x30D0 ?バ) ; KS0-C-2B50
(ucs-set-char #x30D0 ?バ) ; J78-@-2550
(ucs-set-char #x30D0 ?バ) ; GB0-A-2550
(ucs-set-char #x30D0 ?バ) ; J83-B-2550

(ucs-set-char #x30D1 ?パ) ; KS0-C-2B51
(ucs-set-char #x30D1 ?パ) ; J78-@-2551
(ucs-set-char #x30D1 ?パ) ; GB0-A-2551
(ucs-set-char #x30D1 ?パ) ; J83-B-2551

(ucs-set-char #x30D2 ?ヒ) ; KS0-C-2B52
(ucs-set-char #x30D2 ?ヒ) ; J78-@-2552
(ucs-set-char #x30D2 ?ヒ) ; GB0-A-2552
(ucs-set-char #x30D2 ?ヒ) ; J83-B-2552

(ucs-set-char #x30D3 ?ビ) ; KS0-C-2B53
(ucs-set-char #x30D3 ?ビ) ; J78-@-2553
(ucs-set-char #x30D3 ?ビ) ; GB0-A-2553
(ucs-set-char #x30D3 ?ビ) ; J83-B-2553

(ucs-set-char #x30D4 ?ピ) ; KS0-C-2B54
(ucs-set-char #x30D4 ?ピ) ; J78-@-2554
(ucs-set-char #x30D4 ?ピ) ; GB0-A-2554
(ucs-set-char #x30D4 ?ピ) ; J83-B-2554

(ucs-set-char #x30D5 ?フ) ; KS0-C-2B55
(ucs-set-char #x30D5 ?フ) ; J78-@-2555
(ucs-set-char #x30D5 ?フ) ; GB0-A-2555
(ucs-set-char #x30D5 ?フ) ; J83-B-2555

(ucs-set-char #x30D6 ?ブ) ; KS0-C-2B56
(ucs-set-char #x30D6 ?ブ) ; J78-@-2556
(ucs-set-char #x30D6 ?ブ) ; GB0-A-2556
(ucs-set-char #x30D6 ?ブ) ; J83-B-2556

(ucs-set-char #x30D7 ?プ) ; KS0-C-2B57
(ucs-set-char #x30D7 ?プ) ; J78-@-2557
(ucs-set-char #x30D7 ?プ) ; GB0-A-2557
(ucs-set-char #x30D7 ?プ) ; J83-B-2557

(ucs-set-char #x30D8 ?ヘ) ; KS0-C-2B58
(ucs-set-char #x30D8 ?ヘ) ; J78-@-2558
(ucs-set-char #x30D8 ?ヘ) ; GB0-A-2558
(ucs-set-char #x30D8 ?ヘ) ; J83-B-2558

(ucs-set-char #x30D9 ?ベ) ; KS0-C-2B59
(ucs-set-char #x30D9 ?ベ) ; J78-@-2559
(ucs-set-char #x30D9 ?ベ) ; GB0-A-2559
(ucs-set-char #x30D9 ?ベ) ; J83-B-2559

(ucs-set-char #x30DA ?ペ) ; KS0-C-2B5A
(ucs-set-char #x30DA ?ペ) ; J78-@-255A
(ucs-set-char #x30DA ?ペ) ; GB0-A-255A
(ucs-set-char #x30DA ?ペ) ; J83-B-255A

(ucs-set-char #x30DB ?ホ) ; KS0-C-2B5B
(ucs-set-char #x30DB ?ホ) ; J78-@-255B
(ucs-set-char #x30DB ?ホ) ; GB0-A-255B
(ucs-set-char #x30DB ?ホ) ; J83-B-255B

(ucs-set-char #x30DC ?ボ) ; KS0-C-2B5C
(ucs-set-char #x30DC ?ボ) ; J78-@-255C
(ucs-set-char #x30DC ?ボ) ; GB0-A-255C
(ucs-set-char #x30DC ?ボ) ; J83-B-255C

(ucs-set-char #x30DD ?ポ) ; KS0-C-2B5D
(ucs-set-char #x30DD ?ポ) ; J78-@-255D
(ucs-set-char #x30DD ?ポ) ; GB0-A-255D
(ucs-set-char #x30DD ?ポ) ; J83-B-255D

(ucs-set-char #x30DE ?マ) ; KS0-C-2B5E
(ucs-set-char #x30DE ?マ) ; J78-@-255E
(ucs-set-char #x30DE ?マ) ; GB0-A-255E
(ucs-set-char #x30DE ?マ) ; J83-B-255E

(ucs-set-char #x30DF ?ミ) ; KS0-C-2B5F
(ucs-set-char #x30DF ?ミ) ; J78-@-255F
(ucs-set-char #x30DF ?ミ) ; GB0-A-255F
(ucs-set-char #x30DF ?ミ) ; J83-B-255F

(ucs-set-char #x30E0 ?ム) ; KS0-C-2B60
(ucs-set-char #x30E0 ?ム) ; J78-@-2560
(ucs-set-char #x30E0 ?ム) ; GB0-A-2560
(ucs-set-char #x30E0 ?ム) ; J83-B-2560

(ucs-set-char #x30E1 ?メ) ; KS0-C-2B61
(ucs-set-char #x30E1 ?メ) ; J78-@-2561
(ucs-set-char #x30E1 ?メ) ; GB0-A-2561
(ucs-set-char #x30E1 ?メ) ; J83-B-2561

(ucs-set-char #x30E2 ?モ) ; KS0-C-2B62
(ucs-set-char #x30E2 ?モ) ; J78-@-2562
(ucs-set-char #x30E2 ?モ) ; GB0-A-2562
(ucs-set-char #x30E2 ?モ) ; J83-B-2562

(ucs-set-char #x30E3 ?ャ) ; KS0-C-2B63
(ucs-set-char #x30E3 ?ャ) ; J78-@-2563
(ucs-set-char #x30E3 ?ャ) ; GB0-A-2563
(ucs-set-char #x30E3 ?ャ) ; J83-B-2563

(ucs-set-char #x30E4 ?ヤ) ; KS0-C-2B64
(ucs-set-char #x30E4 ?ヤ) ; J78-@-2564
(ucs-set-char #x30E4 ?ヤ) ; GB0-A-2564
(ucs-set-char #x30E4 ?ヤ) ; J83-B-2564

(ucs-set-char #x30E5 ?ュ) ; KS0-C-2B65
(ucs-set-char #x30E5 ?ュ) ; J78-@-2565
(ucs-set-char #x30E5 ?ュ) ; GB0-A-2565
(ucs-set-char #x30E5 ?ュ) ; J83-B-2565

(ucs-set-char #x30E6 ?ユ) ; KS0-C-2B66
(ucs-set-char #x30E6 ?ユ) ; J78-@-2566
(ucs-set-char #x30E6 ?ユ) ; GB0-A-2566
(ucs-set-char #x30E6 ?ユ) ; J83-B-2566

(ucs-set-char #x30E7 ?ョ) ; KS0-C-2B67
(ucs-set-char #x30E7 ?ョ) ; J78-@-2567
(ucs-set-char #x30E7 ?ョ) ; GB0-A-2567
(ucs-set-char #x30E7 ?ョ) ; J83-B-2567

(ucs-set-char #x30E8 ?ヨ) ; KS0-C-2B68
(ucs-set-char #x30E8 ?ヨ) ; J78-@-2568
(ucs-set-char #x30E8 ?ヨ) ; GB0-A-2568
(ucs-set-char #x30E8 ?ヨ) ; J83-B-2568

(ucs-set-char #x30E9 ?ラ) ; KS0-C-2B69
(ucs-set-char #x30E9 ?ラ) ; J78-@-2569
(ucs-set-char #x30E9 ?ラ) ; GB0-A-2569
(ucs-set-char #x30E9 ?ラ) ; J83-B-2569

(ucs-set-char #x30EA ?リ) ; KS0-C-2B6A
(ucs-set-char #x30EA ?リ) ; J78-@-256A
(ucs-set-char #x30EA ?リ) ; GB0-A-256A
(ucs-set-char #x30EA ?リ) ; J83-B-256A

(ucs-set-char #x30EB ?ル) ; KS0-C-2B6B
(ucs-set-char #x30EB ?ル) ; J78-@-256B
(ucs-set-char #x30EB ?ル) ; GB0-A-256B
(ucs-set-char #x30EB ?ル) ; J83-B-256B

(ucs-set-char #x30EC ?レ) ; KS0-C-2B6C
(ucs-set-char #x30EC ?レ) ; J78-@-256C
(ucs-set-char #x30EC ?レ) ; GB0-A-256C
(ucs-set-char #x30EC ?レ) ; J83-B-256C

(ucs-set-char #x30ED ?ロ) ; KS0-C-2B6D
(ucs-set-char #x30ED ?ロ) ; J78-@-256D
(ucs-set-char #x30ED ?ロ) ; GB0-A-256D
(ucs-set-char #x30ED ?ロ) ; J83-B-256D

(ucs-set-char #x30EE ?ヮ) ; KS0-C-2B6E
(ucs-set-char #x30EE ?ヮ) ; J78-@-256E
(ucs-set-char #x30EE ?ヮ) ; GB0-A-256E
(ucs-set-char #x30EE ?ヮ) ; J83-B-256E

(ucs-set-char #x30EF ?ワ) ; KS0-C-2B6F
(ucs-set-char #x30EF ?ワ) ; J78-@-256F
(ucs-set-char #x30EF ?ワ) ; GB0-A-256F
(ucs-set-char #x30EF ?ワ) ; J83-B-256F

(ucs-set-char #x30F0 ?ヰ) ; KS0-C-2B70
(ucs-set-char #x30F0 ?ヰ) ; J78-@-2570
(ucs-set-char #x30F0 ?ヰ) ; GB0-A-2570
(ucs-set-char #x30F0 ?ヰ) ; J83-B-2570

(ucs-set-char #x30F1 ?ヱ) ; KS0-C-2B71
(ucs-set-char #x30F1 ?ヱ) ; J78-@-2571
(ucs-set-char #x30F1 ?ヱ) ; GB0-A-2571
(ucs-set-char #x30F1 ?ヱ) ; J83-B-2571

(ucs-set-char #x30F2 ?ヲ) ; KS0-C-2B72
(ucs-set-char #x30F2 ?ヲ) ; J78-@-2572
(ucs-set-char #x30F2 ?ヲ) ; GB0-A-2572
(ucs-set-char #x30F2 ?ヲ) ; J83-B-2572

(ucs-set-char #x30F3 ?ン) ; KS0-C-2B73
(ucs-set-char #x30F3 ?ン) ; J78-@-2573
(ucs-set-char #x30F3 ?ン) ; GB0-A-2573
(ucs-set-char #x30F3 ?ン) ; J83-B-2573

(ucs-set-char #x30F4 ?ヴ) ; KS0-C-2B74
(ucs-set-char #x30F4 ?ヴ) ; J78-@-2574
(ucs-set-char #x30F4 ?ヴ) ; GB0-A-2574
(ucs-set-char #x30F4 ?ヴ) ; J83-B-2574

(ucs-set-char #x30F5 ?ヵ) ; KS0-C-2B75
(ucs-set-char #x30F5 ?ヵ) ; J78-@-2575
(ucs-set-char #x30F5 ?ヵ) ; GB0-A-2575
(ucs-set-char #x30F5 ?ヵ) ; J83-B-2575

(ucs-set-char #x30F6 ?ヶ) ; KS0-C-2B76
(ucs-set-char #x30F6 ?ヶ) ; J78-@-2576
(ucs-set-char #x30F6 ?ヶ) ; GB0-A-2576
(ucs-set-char #x30F6 ?ヶ) ; J83-B-2576

(ucs-set-char #x30FB ?・) ; GB0-A-2124
(ucs-set-char #x30FB ?・) ; J78-@-2126
(ucs-set-char #x30FB ?・) ; J83-B-2126

(ucs-set-char #x30FC ?ー) ; J78-@-213C
(ucs-set-char #x30FC ?ー) ; J83-B-213C

(ucs-set-char #x30FD ?ヽ) ; J78-@-2133
(ucs-set-char #x30FD ?ヽ) ; J83-B-2133

(ucs-set-char #x30FE ?ヾ) ; J78-@-2134
(ucs-set-char #x30FE ?ヾ) ; J83-B-2134

;;; ucs-katakana.el ends here
