;;; ucs-ss.el --- UCS table of Superscripts and Subscripts

;; Copyright (C) 1998 MORIOKA Tomohiko.

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Keywords: ISO/IEC 10646, Unicode, charset, MULE,
;;           Superscripts and Subscripts

;; This file is part of XEmacs-UCS.

;; XEmacs-UCS is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published
;; by the Free Software Foundation; either version 2, or (at your
;; option) any later version.

;; XEmacs-UCS is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with XEmacs; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
;; 02111-1307, USA.

;;; Code:

(require 'ucs-util)

(ucs-set-char #x2074 ?$(C)y(B) ; KS0-C-2979
(ucs-set-char #x207F ?$(C)z(B) ; KS0-C-297A
(ucs-set-char #x2081 ?$(C){(B) ; KS0-C-297B
(ucs-set-char #x2082 ?$(C)|(B) ; KS0-C-297C
(ucs-set-char #x2083 ?$(C)}(B) ; KS0-C-297D
(ucs-set-char #x2084 ?$(C)~(B) ; KS0-C-297E

;;; ucs-ss.el ends here
