;;; ucs-hebrew.el --- UCS table of Hebrew

;; Copyright (C) 1998 MORIOKA Tomohiko.

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Keywords: ISO/IEC 10646, Unicode, charset, MULE, Hebrew

;; This file is part of XEmacs-UCS.

;; XEmacs-UCS is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published
;; by the Free Software Foundation; either version 2, or (at your
;; option) any later version.

;; XEmacs-UCS is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Code:

(require 'ucs-util)

(ucs-set-char #x05D0 ?›2]-Hà›0]) ; ISO-8859-8-E0-A
(ucs-set-char #x05D1 ?›2]-Há›0]) ; ISO-8859-8-E1-A
(ucs-set-char #x05D2 ?›2]-Hâ›0]) ; ISO-8859-8-E2-A
(ucs-set-char #x05D3 ?›2]-Hã›0]) ; ISO-8859-8-E3-A
(ucs-set-char #x05D4 ?›2]-Hä›0]) ; ISO-8859-8-E4-A
(ucs-set-char #x05D5 ?›2]-Hå›0]) ; ISO-8859-8-E5-A
(ucs-set-char #x05D6 ?›2]-Hæ›0]) ; ISO-8859-8-E6-A
(ucs-set-char #x05D7 ?›2]-Hç›0]) ; ISO-8859-8-E7-A
(ucs-set-char #x05D8 ?›2]-Hè›0]) ; ISO-8859-8-E8-A
(ucs-set-char #x05D9 ?›2]-Hé›0]) ; ISO-8859-8-E9-A
(ucs-set-char #x05DA ?›2]-Hê›0]) ; ISO-8859-8-EA-A
(ucs-set-char #x05DB ?›2]-Hë›0]) ; ISO-8859-8-EB-A
(ucs-set-char #x05DC ?›2]-Hì›0]) ; ISO-8859-8-EC-A
(ucs-set-char #x05DD ?›2]-Hí›0]) ; ISO-8859-8-ED-A
(ucs-set-char #x05DE ?›2]-Hî›0]) ; ISO-8859-8-EE-A
(ucs-set-char #x05DF ?›2]-Hï›0]) ; ISO-8859-8-EF-A
(ucs-set-char #x05E0 ?›2]-Hð›0]) ; ISO-8859-8-F0-A
(ucs-set-char #x05E1 ?›2]-Hñ›0]) ; ISO-8859-8-F1-A
(ucs-set-char #x05E2 ?›2]-Hò›0]) ; ISO-8859-8-F2-A
(ucs-set-char #x05E3 ?›2]-Hó›0]) ; ISO-8859-8-F3-A
(ucs-set-char #x05E4 ?›2]-Hô›0]) ; ISO-8859-8-F4-A
(ucs-set-char #x05E5 ?›2]-Hõ›0]) ; ISO-8859-8-F5-A
(ucs-set-char #x05E6 ?›2]-Hö›0]) ; ISO-8859-8-F6-A
(ucs-set-char #x05E7 ?›2]-H÷›0]) ; ISO-8859-8-F7-A
(ucs-set-char #x05E8 ?›2]-Hø›0]) ; ISO-8859-8-F8-A
(ucs-set-char #x05E9 ?›2]-Hù›0]) ; ISO-8859-8-F9-A
(ucs-set-char #x05EA ?›2]-Hú›0]) ; ISO-8859-8-FA-A

;;; ucs-hebrew.el ends here
